@@ -12,7 +12,13 @@ use vm_memory::{
 };
 
 use crate::defs::{VIRTQ_AVAIL_ELEMENT_SIZE, VIRTQ_AVAIL_RING_HEADER_SIZE};
-use crate::{Descriptor, DescriptorChain, Error, Queue, QueueOwnedT, QueueT, VirtqUsedElem};
+use crate::{
+    desc::{
+        split::{Descriptor as SplitDescriptor, VirtqUsedElem},
+        RawDescriptor,
+    },
+    DescriptorChain, Error, Queue, QueueOwnedT, QueueT,
+};
 use std::fmt::{self, Debug, Display};
 use virtio_bindings::bindings::virtio_ring::{VRING_DESC_F_INDIRECT, VRING_DESC_F_NEXT};
 
@@ -177,7 +183,7 @@ pub type UsedRing<'a, M> = SplitQueueRing<'a, M, VirtqUsedElem>;
 
 /// Refers to the buffers the driver is using for the device.
 pub struct DescriptorTable<'a, M> {
-    table: ArrayRef<'a, M, Descriptor>,
+    table: ArrayRef<'a, M, RawDescriptor>,
     len: u16,
     free_descriptors: Vec<u16>,
 }
@@ -196,14 +202,14 @@ impl<'a, M: GuestMemory> DescriptorTable<'a, M> {
     }
 
     /// Read one descriptor from the specified index.
-    pub fn load(&self, index: u16) -> Result<Descriptor, MockError> {
+    pub fn load(&self, index: u16) -> Result<RawDescriptor, MockError> {
         self.table
             .ref_at(index as usize)
             .map(|load_ref| load_ref.load())
     }
 
     /// Write one descriptor at the specified index.
-    pub fn store(&self, index: u16, value: Descriptor) -> Result<(), MockError> {
+    pub fn store(&self, index: u16, value: RawDescriptor) -> Result<(), MockError> {
         self.table
             .ref_at(index as usize)
             .map(|store_ref| store_ref.store(value))
@@ -211,7 +217,7 @@ impl<'a, M: GuestMemory> DescriptorTable<'a, M> {
 
     /// Return the total size of the DescriptorTable in bytes.
     pub fn total_size(&self) -> u64 {
-        (self.len as usize * size_of::<Descriptor>()) as u64
+        (self.len as usize * size_of::<RawDescriptor>()) as u64
     }
 
     /// Create a chain of descriptors.
@@ -228,7 +234,7 @@ impl<'a, M: GuestMemory> DescriptorTable<'a, M> {
 
         for (pos, index_value) in indices.iter().copied().enumerate() {
             // Addresses and lens constant for now.
-            let mut desc = Descriptor::new(0x1000, 0x1000, 0, 0);
+            let mut desc = SplitDescriptor::new(0x1000, 0x1000, 0, 0);
 
             // It's not the last descriptor in the chain.
             if pos < indices.len() - 1 {
@@ -237,6 +243,8 @@ impl<'a, M: GuestMemory> DescriptorTable<'a, M> {
             } else {
                 desc.set_flags(0);
             }
+
+            let desc = RawDescriptor::from(desc);
             self.store(index_value, desc)?;
         }
 
@@ -322,12 +330,12 @@ impl<'a, M: GuestMemory> MockSplitQueue<'a, M> {
     }
 
     /// Available ring accessor.
-    pub fn avail(&self) -> &AvailRing<M> {
+    pub fn avail(&self) -> &AvailRing<'_, M> {
         &self.avail
     }
 
     /// Used ring accessor.
-    pub fn used(&self) -> &UsedRing<M> {
+    pub fn used(&self) -> &UsedRing<'_, M> {
         &self.used
     }
 
@@ -389,12 +397,13 @@ impl<'a, M: GuestMemory> MockSplitQueue<'a, M> {
         // We just allocate the indirect table and forget about it for now.
         let indirect_addr = self.alloc_indirect_chain(len)?;
 
-        let mut desc = self.desc_table.load(head_idx)?;
+        let desc = self.desc_table.load(head_idx)?;
+        let mut desc = SplitDescriptor::from(desc);
         desc.set_flags(VRING_DESC_F_INDIRECT as u16);
         desc.set_addr(indirect_addr.raw_value());
-        desc.set_len(u32::from(len) * size_of::<Descriptor>() as u32);
+        desc.set_len(u32::from(len) * size_of::<RawDescriptor>() as u32);
 
-        self.desc_table.store(head_idx, desc)?;
+        self.desc_table.store(head_idx, RawDescriptor::from(desc))?;
         self.update_avail_idx(head_idx)
     }
 
@@ -424,7 +433,7 @@ impl<'a, M: GuestMemory> MockSplitQueue<'a, M> {
     /// the descriptor table, and returns the first `DescriptorChain` available.
     pub fn build_multiple_desc_chains(
         &self,
-        descs: &[Descriptor],
+        descs: &[RawDescriptor],
     ) -> Result<DescriptorChain<&M>, MockError> {
         self.add_desc_chains(descs, 0)?;
         self.create_queue::<Queue>()
@@ -442,9 +451,13 @@ impl<'a, M: GuestMemory> MockSplitQueue<'a, M> {
     // TODO: make this function work with a generic queue. For now that's not possible because
     // we cannot create the descriptor chain from an iterator as iterator is not implemented for
     // a generic T, just for `Queue`.
-    pub fn build_desc_chain(&self, descs: &[Descriptor]) -> Result<DescriptorChain<&M>, MockError> {
-        let mut modified_descs: Vec<Descriptor> = Vec::with_capacity(descs.len());
+    pub fn build_desc_chain(
+        &self,
+        descs: &[RawDescriptor],
+    ) -> Result<DescriptorChain<&M>, MockError> {
+        let mut modified_descs: Vec<RawDescriptor> = Vec::with_capacity(descs.len());
         for (idx, desc) in descs.iter().enumerate() {
+            let desc = SplitDescriptor::from(*desc);
             let (flags, next) = if idx == descs.len() - 1 {
                 // Clear the NEXT flag if it was set. The value of the next field of the
                 // Descriptor doesn't matter at this point.
@@ -454,7 +467,12 @@ impl<'a, M: GuestMemory> MockSplitQueue<'a, M> {
                 // descriptor. This ignores any value is actually present in `desc.next`.
                 (desc.flags() | VRING_DESC_F_NEXT as u16, idx as u16 + 1)
             };
-            modified_descs.push(Descriptor::new(desc.addr().0, desc.len(), flags, next));
+            modified_descs.push(RawDescriptor::from(SplitDescriptor::new(
+                desc.addr().0,
+                desc.len(),
+                flags,
+                next,
+            )));
         }
         self.build_multiple_desc_chains(&modified_descs[..])
     }
@@ -465,7 +483,7 @@ impl<'a, M: GuestMemory> MockSplitQueue<'a, M> {
     // The descriptor chain related information is written in memory starting with address 0.
     // The `addr` fields of the input descriptors should start at a sufficiently
     // greater location (i.e. 1MiB, or `0x10_0000`).
-    pub fn add_desc_chains(&self, descs: &[Descriptor], offset: u16) -> Result<(), MockError> {
+    pub fn add_desc_chains(&self, descs: &[RawDescriptor], offset: u16) -> Result<(), MockError> {
         let mut new_entries = 0;
         let avail_idx: u16 = self
             .mem
@@ -477,7 +495,9 @@ impl<'a, M: GuestMemory> MockSplitQueue<'a, M> {
             let i = idx as u16 + offset;
             self.desc_table().store(i, *desc)?;
 
-            if idx == 0 || descs[idx - 1].flags() & VRING_DESC_F_NEXT as u16 != 1 {
+            if idx == 0
+                || SplitDescriptor::from(descs[idx - 1]).flags() & VRING_DESC_F_NEXT as u16 != 1
+            {
                 // Update the available ring position.
                 self.mem
                     .write_obj(
